@@ -5,7 +5,7 @@ use warnings;
 use POSIX;
 
 use vars qw($VERSION);
-$VERSION = '0.16';
+$VERSION = '1.00';
 
 #----------------------------------------------------------------------------
 
@@ -70,9 +70,8 @@ sub _InterpretWin32Info
 {
     my $self = shift;
     my @versionInfo = @_;
-    my ($string, $major, $minor, $build, $id, $spmajor, $spminor, $suitemask, $producttype, @extra)  = @versionInfo;
-    my ($osname, $oslabel, $version, $source);
-    my %info;
+    my ($string, $major, $minor, $build, $id, $spmajor, $spminor, $suitemask, $producttype, @extra) = @versionInfo;
+    my ($osname);
     my $NTWORKSTATION = 1;
     if($major == 5 && $minor == 2 && $producttype == $NTWORKSTATION)
     {
@@ -214,7 +213,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2016 Birmingham Perl Mongers
+  Copyright (C) 2010-2019 Birmingham Perl Mongers
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
